![pySBOL3 logo](logos/pySBOL3-logo-small.jpeg)
# pySBOL3
![gh-action badge](https://github.com/SynBioDex/pySBOL3/workflows/Python%20package/badge.svg)
![readthedocs badge](https://readthedocs.org/projects/pysbol3/badge/)

pySBOL3 is a
[Python](https://www.python.org/) implementation of the [SBOL 3
specification](https://sbolstandard.org/datamodel-specification/).
pySBOL3 implements [SBOL
3.0.1](https://sbolstandard.org/docs/SBOL3.0.1.pdf).

## Installation

pySBOL3 requires [Python 3.7](https://www.python.org) or newer.

Use `pip` (or `pip3`) to install the library:

```
pip install sbol3
```

## Documentation

[Documentation for pySBOL3 is available at read-the-docs](https://pysbol3.readthedocs.io).

## Development

Please
[fork the GitHub repository](https://guides.github.com/activities/forking/),
and follow
[GitHub flow](https://guides.github.com/introduction/flow/)
for development.

## Acknowledgements

If you use pySBOL3 please cite:
> Tom Mitchell, Jacob Beal, and Bryan Bartley.
> [pySBOL3: SBOL3 for Python Programmers](https://doi.org/10.1021/acssynbio.2c00249).
> ACS Synthetic Biology, available online June 29, 2022. PMID: 35767721.

Development of this library has been supported by the 
[DARPA Synergistic Discovery and Design (SD2)](https://www.darpa.mil/program/synergistic-discovery-and-design)
program and [Raytheon BBN Technologies](http://bbn.com/).
